Learn R Programming

nivo.bubblechart (version 0.1.1)

bubblechart-shiny: Shiny bindings for bubblechart

Description

Output and render functions for using bubblechart within Shiny applications and interactive Rmd documents.

Usage

bubblechartOutput(outputId, width = "100%", height = "400px")

renderBubblechart(expr, env = parent.frame(), quoted = FALSE)

Value

For bubblechartOutput, a Shiny UI element that can be included in a Shiny UI definition. For renderBubblechart, a Shiny render function that can be assigned to an output slot in a Shiny server function.

Arguments

outputId

output variable to read from

width, height

Must be a valid CSS unit (like '100 percent', '400px', 'auto') or a number, which will be coerced to a string and have 'px' appended.

expr

An expression that generates a bubblechart

env

The environment in which to evaluate expr.

quoted

Is expr a quoted expression (with quote())? This is useful if you want to save an expression in a variable.